============
Installation
============

At the command line::

    pip install signposting

If you are installing from `source code`_::

    pip install .

.. source code: https://github.com/stain/signposting/